/*
 *  Copyright 2008 by Spectrum Digital Incorporated.
 *  All rights reserved. Property of Spectrum Digital Incorporated.
 */

/*
 *  GPIO Expander implementation
 *
 */

#include "evmomapl137_i2cgpio.h"

/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  _I2CGPIO_init( )                                                       *
 *      Setup I2C GPIO                                                      *
 *                                                                          *
 * ------------------------------------------------------------------------ */
Int16 EVMOMAPL137_I2CGPIO_init( )
{
    return 0;
}

/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  _I2CGPIO_getall( id, input )                                           *
 *      Read all GPIOs in a particular group                                *
 *                                                                          *
 *      Inputs:                                                             *
 *              id     -> I2C GPIO Expander ID                              *
 *              input  -> byte                                              *
 *                                                                          *
 * ------------------------------------------------------------------------ */
Int16 EVMOMAPL137_I2CGPIO_getall( Uint16 id, Uint8 *input )
{
    Int16 retcode = EVMOMAPL137_I2C_read( id, input, 1 );

    /* Pause for the I2C GPIO to reset its state machine */
    EVMOMAPL137_waitusec( 50 );

    return retcode;
}

/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  _I2CGPIO_setall( id, output )                                          *
 *      Set all GPIOs in a particular group.                                *
 *                                                                          *
 *      Inputs:                                                             *
 *              id     -> I2C GPIO Expander ID                              *
 *              output -> byte                                              *
 *                                                                          *
 * ------------------------------------------------------------------------ */
Int16 EVMOMAPL137_I2CGPIO_setall( Uint16 id, Uint8 output )
{
    return EVMOMAPL137_I2C_write( id, &output, 1 );
}

/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  _I2CGPIO_setOutput( id, number, output )                               *
 *      Set 1 GPIO in a particular group                                    *
 *                                                                          *
 *      Inputs:                                                             *
 *              id     -> I2C GPIO Expander ID                              *
 *              number -> GPIO PIN# [0:7]                                   *
 *              output -> [0:LOW][1:HIGH]                                   *
 *                                                                          *
 *      Returns:                                                            *
 *              0: Good                                                     *
 *             -1: Error                                                    *
 *                                                                          *
 * ------------------------------------------------------------------------ */
Int16 EVMOMAPL137_I2CGPIO_setOutput( Uint16 id, Uint8 number, Uint8 output )
{
    Uint8 gpio_state;
    Int16 retcode;

    output = ( output & 1 );
    number = ( 1 << ( number & 7 ) );

    if ( retcode = EVMOMAPL137_I2CGPIO_getall( id, &gpio_state ) )
        return retcode;

    /* Output is Low */
    if ( output == 0 )
        gpio_state = ( gpio_state & ( ~number ) );

    /* Output is High */
    else
        gpio_state = ( gpio_state | number );

    if ( retcode = EVMOMAPL137_I2CGPIO_setall( id, gpio_state ) )
        return retcode;

    return 0;
}

/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  _I2CGPIO_getInput( id, number )                                        *
 *      Get 1 GPIO in a particular group                                    *
 *                                                                          *
 *      Inputs:                                                             *
 *              id     -> I2C GPIO Expander ID                              *
 *              number -> GPIO PIN# [0:7]                                   *
 *                                                                          *
 *      Returns:                                                            *
 *              0: Input is LOW                                             *
 *              1: Input is HIGH                                            *
 *             -1: Error                                                    *
 *                                                                          *
 * ------------------------------------------------------------------------ */
Int16 EVMOMAPL137_I2CGPIO_getInput( Uint16 id, Uint8 number )
{
    Uint8 input = 0;

    if ( EVMOMAPL137_I2CGPIO_getall( id, &input ) )
        return -1;

    /* Return either 0 or 1 */
    return ( input >> ( number & 7 ) ) & 1;
}
